Signature Window Attention Units
================================

.. automodule:: sig_networks.swmhau
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: sig_networks.swmhau_network
   :members:
   :undoc-members:
   :show-inheritance:
